from setuptools import setup

setup(
    name='rwproperty',
    version='1.0',
    author='Philipp von Weitershausen',
    author_email='grok-dev@zope.org',
    url='http://www.z3lab.org/sections/blogs/philipp-weitershausen/2006_05_29_pycon-06-lightning-talk',
    download_url='http://codespeak.net/svn/user/philikon/rwproperty#egg=rwproperty-dev',
    description='Read & write properties',
    long_description=open('rwproperty.txt').read(),
    license='ZPL',
    
    py_modules=['rwproperty']
)
